@@ -3,13 +3,12 @@ import multiprocessing
 import os
 from functools import partial
 from multiprocessing import Pool
-from multiprocessing.pool import ThreadPool
 from pathlib import Path
 from typing import List, Union, Tuple, Optional
 
 import numpy as np
 import pyproj
-from ipyleaflet import Map, Polyline, Marker, Icon, FullScreenControl, ScaleControl, basemap_to_tiles, TileLayer
+from ipyleaflet import Map, Polyline, Marker, Icon, FullScreenControl, ScaleControl, TileLayer
 from ipywidgets import HTML
 from tqdm.auto import tqdm
 
@@ -317,7 +316,6 @@ class Campaign:
         m.add_control(FullScreenControl())
 
         # Add map
-        #osm_layer = basemap_to_tiles(open_railway_map)
         m.add_layer(open_railway_map)
 
         # Plot GPS point for each measurement and OSM Tracks
